@@ -1,7 +1,9 @@
 from .base import init_base_logger
 from .colored import init_colored_logger
+from .common import log
 
 __all__ = [
     "init_base_logger",
     "init_colored_logger",
+    "log",
 ]
