@@ -2,7 +2,7 @@ import logging
 
 
 def init_base_logger():
-    fmt = "{asctime} [{levelname}] {filename}.{funcName}:{lineno} {message}"
+    fmt = "{asctime} [{levelname}] {filename}.{funcName}:{lineno} | {message}"
 
     logging.basicConfig(
         level=logging.DEBUG,
